Skip to contents

Implement population-based hybrid-optimization algorithms. Separate a problem into two steps, define methods for initializing a population of first-step guesses, optimizing the second step, and updating the population, all with comprehensive helpers and error handling.

Author

Maintainer: Ricardo Semião ricardo.semiao@outlook.com